pyrailway
=========

A High-Level Architecture for Python Web Applications based on
Trailblazer / Railway Oriented Programming

License
-------

MIT, see LICENSE

References
----------

-  `Railway Oriented
   Programming <https://fsharpforfunandprofit.com/rop>`__
-  `Trailblazer <https://trailblazer.to>`__
